calc_change_in_ml: calc_change_in_ml
Description
Calculate the change in the log marginal likelihood after moving index to each possible cluster
Usage
calc_change_in_ml(snp.object, partition, indexes)
Value
the best cluster to move indexes to.
Arguments
- snp.object
A snp.object containing the processed SNP data.
- partition
An integer vector indicating a partition of the isolates.
- indexes
Indexes of the isolates to be moved (must come from one cluster.)