Peform an iteration of the first move in the algorithm. That is move units from one cluster to another to improve the marginal likelihood
move_units_1(
snp.object,
partition,
threshold = 1e-05,
frac.clust.searched = 0.3,
min.clust.size = 20,
n.cores = 1
)The best partition after moving units from one cluster to another as well as a boolean value indicating whether a move increased the marginal likelihood.
A snp.object containing the processed SNP data.
An integer vector indicating an initial partition of the isolates.
The increase in marginal log likelihood required to accept a move.
The percentage of a large cluster that will be moved.
All isolates in clusters less than or equal to min.clus.size will be searched.
The number of cores to use.