Peform an iteration of the fourth move in the algorithm. That is split cluster into n subclusters and re-allocate one sub-cluster.
reallocate_units_4(
snp.object,
partition,
threshold = 1e-05,
min.clust.size = 20,
split = FALSE,
n.cores = 1
)The best partition after splitting a cluster and re-allocating as well as a boolean value indicating whether a move increased the marginal likelihood.
A snp.object containing the processed SNP data.
An integer vector indicating an initial partition of the isolates.
The increase in marginal log likelihood required to accept a move.
Clusters smaller than min.clust.size will not be split.
Whether to split only into two clusters (for move type 3).
The number of cores to use.